## Waybackeasy
The insanely simple way to interface with the WayBackMachine.

### Install
```pip install waybackeasy```

### Use
```import waybackeasy```

```waybackeasy.get("https://news.ycombinator.com", "27.05.2016")```

returns html of news.ycombinator.com on the 27th of May, 2016 as recorded by the WB-machine.

### Dateformat
```dd.mm.yyyy```

I'm planning to improve this and add more useful options in the future.

### Contact

For feedback, bug-reports or feature-requests, write me - joseikowsky@gmail.com
